@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#Copyright (C) 2006 - 2008 NTT DATA Corporation
+#Copyright (C) since 2006 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -27,15 +27,15 @@ SSH_KEYGEN="/usr/bin/ssh-keygen -t rsa"
 MKDIR=/bin/mkdir
 CHMOD=/bin/chmod
 
+VERSION=`cat ${HINEMOS_HOME}/_version`
 
 echo ""
-
 echo "###################################################################"
-echo "###                                                             ###"
-echo "###              運用管理ソフトウェア Hinemos                   ###"
-echo "###                  一括制御 セットアップスクリプト  Ver 2.4.1 ###"
-echo "###                                                             ###"
-echo "###  Copyright (C) 2006 - 2008 NTT DATA Corporation.            ###"
+echo "###"
+echo "###              運用管理ソフトウェア Hinemos"
+echo "###            一括制御 セットアップスクリプト  Ver. ${VERSION}"
+echo "###"
+echo "###  Copyright (C) since 2006 NTT DATA Corporation."
 echo "###################################################################"
 
 
@@ -71,7 +71,7 @@ setup() {
     fi
 
     expect -c "
-        set timeout 1
+        set timeout 20
         spawn -noecho $SSH_KEYGEN
         expect Enter
         send \r
@@ -149,10 +149,10 @@ entry() {
 		AGENT_AUTHORIZED_KEYS=${ROOT_HOME}.ssh/authorized_keys
 		case ${ANS} in
 		    y|Y)
-			ssh root@${AGENT_IP} command "
-                            if [ ! -d ${ROOT_HOME}/.ssh ] ; then
-                                ${MKDIR} ${ROOT_HOME}/.ssh
-                                ${CHMOD} 700 ${ROOT_HOME}/.ssh
+			ssh root@${AGENT_IP} "
+                            if [ ! -d ${ROOT_HOME}.ssh ] ; then
+                                ${MKDIR} ${ROOT_HOME}.ssh
+                                ${CHMOD} 700 ${ROOT_HOME}.ssh
                             fi
                             echo ${MANAGER_KEY} >> ${AGENT_AUTHORIZED_KEYS}
                             ${CHMOD} 600 ${AGENT_AUTHORIZED_KEYS}
